setlocal
@echo off

:GETINFO
echo.
echo *************************************************************
echo   Clean up Data in stageDDS/CIDDS/SASSDM (Common/ODCS/FM/OP) 
echo *************************************************************
echo.

echo -------------------------------------------------------------
echo DB Authentication Information 
echo -------------------------------------------------------------
set DB_PORT=3306

set DB_HOST=
set DB_NAME=sassdm
set DB_USERID=
set DB_PASSWD=


rem **********************************************************************
rem If the path for mySQL executable is not correctly assigned 
rem substitute c:\mySQL\bin below with correct one
rem **********************************************************************
set DB_UTIL=c:\mySQL\bin
set DB_MYSQL=%DB_UTIL%\mysql.exe

set /p DB_HOST=MySQL Host Name :
echo.
set /p DB_NAME=MySQL DB Name (default:sassdm) :
echo.
set /p DB_PORT=MySQL Port (default:3306) :
echo.
set /p DB_USERID=MySQL DB User ID :
echo.
set /p DB_PASSWD=MySQL DB User Password :
echo.

echo -------------------------------------------------------------
echo Metadata Server Authentication Information
echo -------------------------------------------------------------
set SYSPARM_OPT=5.1,INSTALLATION
set SAS_EXE=C:\Program Files\SAS\SASFoundation\9.2\sas.exe
set SAS_CONFIG=C:\SAS\Config\Lev1\SASApp\sasv9.cfg

set META_USER_ID=
set META_USER_PW=

set /p META_USER_ID=Metadata Server User ID :
echo.
set /p META_USER_PW=Metadata Server User PW :
echo.



rem ***********************************************************************
rem         Check the existence of SAS
rem ***********************************************************************
:CHECK_SAS
if exist "%SAS_EXE%" goto CHECK_CONFIG
echo.
echo **********************************************************************
echo ERROR: sas.exe was not found at %SAS_EXE%
echo **********************************************************************
goto END

rem ***********************************************************************
rem         Check the existence of SAS configuration
rem ***********************************************************************
:CHECK_CONFIG
if exist "%SAS_CONFIG%" goto BEGIN_CLEANUP
echo.
echo **********************************************************************
echo ERROR: sasv9.cfg was not found at %SAS_CONFIG%
echo **********************************************************************
goto END



:BEGIN_CLEANUP
rem **************************************************************************************************************
rem                          List of clean up and install programs
rem **************************************************************************************************************
set REG_STAGEDDS_DDS=C:\SAS\Config\Lev1\Applications\SASSolutionsServices5.1\SASCode\register_stagedds_and_dds.sas
set REG_COMMON=C:\SAS\Config\Lev1\Applications\SASSolutionsServices5.1\SASCode\register_common.sas
set REG_ODCS=C:\SAS\Config\Lev1\Applications\SASSolutionsServices5.1\SASCode\register_odcs.sas
set REG_FM=C:\SAS\Config\Lev1\Applications\SASFinancialManagement5.1\SASCode\register_fm.sas
set REG_OP=C:\SAS\Config\Lev1\Applications\SASFinancialManagement5.1\SASCode\register_opplan.sas


rem ***********************************************************************
rem         Check the existence of necessary programs listed above
rem ***********************************************************************
:CHECK_STAGEDDS_DDS
if exist "%REG_STAGEDDS_DDS%" goto CHECK_COMMON
echo.
echo **********************************************************************
echo ERROR: register_stagedds_and_dds.sas was not found at %REG_STAGEDDS_DDS%
echo        Please modify value of REG_STAGEDDS_DDS variable with correct 
echo        location in this batch program and then run it again.
echo **********************************************************************
goto END

:CHECK_COMMON
if exist "%REG_COMMON%" goto CHECK_ODCS
echo.
echo **********************************************************************
echo ERROR: register_common.sas was not found at %REG_COMMON%
echo        Please modify value of REG_COMMON variable with correct 
echo        location in this batch program and then run it again.
echo **********************************************************************
goto END

:CHECK_ODCS
if exist "%REG_ODCS%" goto CHECK_FM
echo.
echo **********************************************************************
echo ERROR: register_odcs.sas was not found at %REG_ODCS%
echo        Please modify value of REG_ODCS variable with correct 
echo        location in this batch program and then run it again.
echo **********************************************************************
goto END

:CHECK_FM
if exist "%REG_FM%" goto CHECK_OP
echo.
echo **********************************************************************
echo ERROR: register_fm.sas was not found at %REG_FM%
echo        Please modify value of REG_FM variable with correct 
echo        location in this batch program and then run it again.
echo **********************************************************************
goto END

:CHECK_OP
if exist "%REG_OP%" goto RUN_REG_PRG
echo.
echo **********************************************************************
echo ERROR: register_opplan.sas was not found at %REG_OP%
echo        Please modify value of REG_OP variable with correct 
echo        location in this batch program and then run it again.
echo **********************************************************************
goto END


rem ***********************************************************************
rem        Removing Data and Running Registration Programs
rem ***********************************************************************
:RUN_REG_PRG
echo --- Recreating SASSDM schema ---
"%DB_MYSQL%" -h%DB_HOST% -u%DB_USERID% -p%DB_PASSWD% %DB_NAME% -e "drop database sassdm;create database sassdm;"
echo --- Recreating STAGEDDS and DDS ---
"%SAS_EXE%" "%REG_STAGEDDS_DDS%" -config "%SAS_CONFIG%"  -metauser %META_USER_ID% -metapass %META_USER_PW% -sysparm "%SYSPARM_OPT%"
echo --- Recreating Common in SASSDM ---
"%SAS_EXE%" "%REG_COMMON%" -config "%SAS_CONFIG%"  -metauser %META_USER_ID% -metapass %META_USER_PW% -sysparm "%SYSPARM_OPT%"
echo --- Recreating ODCS in SASSDM ---
"%SAS_EXE%" "%REG_ODCS%" -config "%SAS_CONFIG%"  -metauser %META_USER_ID% -metapass %META_USER_PW% -sysparm "%SYSPARM_OPT%"
echo --- Recreating FM in SASSDM ---
"%SAS_EXE%" "%REG_FM%" -config "%SAS_CONFIG%"  -metauser %META_USER_ID% -metapass %META_USER_PW% -sysparm "%SYSPARM_OPT%"
echo --- Recreating OP in SASSDM ---
"%SAS_EXE%" "%REG_OP%" -config "%SAS_CONFIG%"  -metauser %META_USER_ID% -metapass %META_USER_PW% -sysparm "%SYSPARM_OPT%"

echo.
echo *********************************************************************
echo Program finished.
echo Please check the following output logs for details:
echo     register_stagedds_and_dds.log
echo     register_common.log
echo     register_odcs.log
echo     register_fm.log
echo     register_opplan.log
echo *********************************************************************
echo.


:END
endlocal